@@ -12,7 +12,6 @@ import requests
 from edtf import parse_edtf
 from flask import Blueprint, render_template
 from invenio_cache import current_cache
-from invenio_rdm_records.vocabularies import Vocabularies
 
 
 def fetch_schemaorg_jsonld(doi_url):
@@ -29,7 +28,7 @@ def fetch_schemaorg_jsonld(doi_url):
             )
             if response.status_code == 200:
                 metadata = response.text.strip()
-                curent_cache.set(key, metadata)
+                current_cache.set(key, metadata)
 
         except Exception:
             pass
