@@ -16,15 +16,18 @@ theme = WebpackThemeBundle(
     themes={
         "semantic-ui": {
             "entry": {
-                "invenio-theme-tuw-theme": "./less/invenio_theme_tuw/theme.less",
                 "invenio-theme-tuw-tracking": "./js/invenio_theme_tuw/tracking/index.js",
                 "invenio-theme-tuw-mobilemenu": "./js/invenio_theme_tuw/mobilemenu/index.js",
                 "invenio-theme-tuw-messages": "./js/invenio_theme_tuw/messages/index.js",
                 "invenio-theme-tuw-pdf-preview": "./js/invenio_theme_tuw/pdf-preview/index.js",
+                "invenio-theme-tuw-sticky-header": "./js/invenio_theme_tuw/sticky-header/index.js"
             },
             "dependencies": {
                 "jquery": "^3.2.1",
             },
+            "aliases": {
+                "themes/tuw": "less/invenio_theme_tuw/theme",
+            }
         },
     },
 )
